package at.ac.uibk.gitsearch.service;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.codeability.sharing.plugins.api.search.SearchResultDTO;
import org.codeability.sharing.plugins.api.search.SearchResultsDTO;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import at.ac.uibk.gitsearch.repository.StatisticsRepository;
import at.ac.uibk.gitsearch.service.dto.StatisticsDTO;

@Service
@Transactional
public class AchievementService {
    
    private final Logger log = LoggerFactory.getLogger(AchievementService.class);

    private final SearchService searchService;

    private final StatisticsService statisticsService;

    private final UserService userService;

    private final StatisticsRepository statisticsRepository;

    public AchievementService(SearchService searchService, StatisticsService statisticsService, UserService userService, StatisticsRepository statisticsRepository) {
        this.searchService = searchService;
        this.statisticsService = statisticsService;
        this.userService = userService;
        this.statisticsRepository = statisticsRepository;
    }

 
    public StatisticsDTO searchUserStatistics(String email) throws IOException {
  
        SearchResultsDTO results = searchService.searchResultForAuthorEmail(email, 1000);


        List<SearchResultDTO> result = results.getSearchResult();
        List<String> query = new ArrayList<String>();
        for (int i = 0; i < result.size() ; i++) {
                query.add(result.get(i).getExerciseId());
        }

        StatisticsDTO toReturn = new StatisticsDTO();
        Optional<Integer> totalAmountOfDownloads = statisticsRepository.findNumberOfDownloadsByExerciseIDs(query);
        Optional<Integer> totalAmountOfViews = statisticsRepository.findNumberOfViewsByExerciseIDs(query);

        if(totalAmountOfDownloads.isPresent()){
            toReturn.setDownloads(totalAmountOfDownloads.get());
        }else {
            toReturn.setDownloads(0);

        }
        if(totalAmountOfViews.isPresent()){
            toReturn.setViews(totalAmountOfViews.get());
        }else {
            toReturn.setViews(0);

        }

        log.info("Returning " + toReturn.getViews() + " views and " + toReturn.getDownloads() + " downloads");
        return toReturn;
    
    
    }

}



// Maybe to use later
// Optional<StatisticsDTO> statisticsDTO = statisticsService.findOneByExerciseID((result.getExerciseId()));
// if (statisticsDTO.isPresent()) {
// StatisticsDTO newStats = statisticsDTO.get();
//     totalAmountOfViews += newStats.getViews();
//     totalAmountOfDownloads += newStats.getDownloads();
// }