import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { Exercise } from 'app/shared/model/exercise.model';
import { SearchService } from 'app/search/service/search-service';
import { Statistics } from 'app/shared/model/statistics.model';
import { WatchlistManager } from 'app/shared/watchlist/watchlist-manager';
import { LikesService } from 'app/entities/likes/likes.service';

@Component({
  selector: 'jhi-exercise-card',
  templateUrl: './exercise-card.component.html',
  styleUrls: ['./exercise-card.component.scss'],
})
export class ExerciseCardComponent implements OnInit {
  @Input() exercise: Exercise | undefined;

  @Output() exerciseSelectionEvent = new EventEmitter<Exercise>();

  constructor(protected searchService: SearchService, private watchlistManager: WatchlistManager, private likesService: LikesService) {}

  ngOnInit(): void {}

  selectExercise(): void {
    if (this.exercise !== undefined) {
      this.exercise.views = 0;
      this.exercise.downloads = 0;

      this.likesService.getLikesForexerciseID(this.exercise.originalResult.project.project_id).subscribe(
        (data: number) => {
          this.exercise!.numberOfLikes = data;
        },
        () => alert('Could not load number of likes')
      );

      this.likesService.hasLiked(this.exercise.originalResult.project.project_id).subscribe(
        (data: boolean) => {
          this.exercise!.userHasLiked = data;
        },
        () => alert('Could not load if user has liked or not')
      );

      this.searchService.getStatisticsForExercise(this.exercise.originalResult.exerciseId).subscribe(
        (data: Statistics) => {
          this.exercise!.views = data.views!;
          this.exercise!.downloads = data.downloads!;
        },
        () => alert('Could not load exercise statistics')
      );
    }
    this.exerciseSelectionEvent.emit(this.exercise);
  }

  isOnCurrentWatchlist(e: Exercise): boolean {
    return this.watchlistManager.isExerciseOnCurrentWatchlist(e);
  }

  handleForCurrentWatchlist(e: Exercise) {
    this.watchlistManager.handleCheckForCurrentWatchlist(e);
  }

  /**
   * correct missing image urls
   */
  correctImageURL(event: Event): void {
    if (event.srcElement) {
      event.srcElement['src'] = '/content/images/Logo_codeAbility_4c_300dpi_RGB3.gif';
    }
  }
}
